@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2023  Błażej Szczygieł
+    Copyright (C) 2010-2025  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -18,20 +18,8 @@
 
 #include <Equalizer.hpp>
 
-extern "C"
-{
-    #include <libavutil/mem.h>
-    #include <libavcodec/avfft.h>
-}
-
 #include <cmath>
 
-static inline void fft_calc(FFTContext *fft_ctx, FFTComplex *cplx)
-{
-    av_fft_permute(fft_ctx, cplx);
-    av_fft_calc(fft_ctx, cplx);
-}
-
 static inline float cosI(const float y1, const float y2, float p)
 {
     p = (1.0f - cos(p * static_cast<float>(M_PI))) / 2.0f;
@@ -77,9 +65,6 @@ float Equalizer::getAmpl(int val)
 }
 
 Equalizer::Equalizer(Module &module)
-#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
-    : m_mutex(QMutex::Recursive)
-#endif
 {
     SetModule(module);
 }
@@ -165,7 +150,7 @@ double Equalizer::filter(QByteArray &data, bool flush)
         for (int c = 0; c < chn; ++c)
         {
             int pos = c;
-            while (m_input[c].size() >= fftSize)
+            while (static_cast<int>(m_input[c].size()) >= fftSize)
             {
                 for (int i = 0; i < fftSize; ++i)
                 {
@@ -178,7 +163,7 @@ double Equalizer::filter(QByteArray &data, bool flush)
                 else
                     m_input[c].clear();
 
-                fft_calc(m_fftIn, m_complex);
+                m_fftIn.calc(m_complex);
                 for (int i = 0; i < fftSizeDiv2; ++i)
                 {
                     const float coeff = m_f[i] * m_preamp;
@@ -187,7 +172,7 @@ double Equalizer::filter(QByteArray &data, bool flush)
                     m_complex[fftSize - 1 - i].re *= coeff;
                     m_complex[fftSize - 1 - i].im *= coeff;
                 }
-                fft_calc(m_fftOut, m_complex);
+                m_fftOut.calc(m_complex);
 
                 if (m_lastSamples[c].empty())
                 {
@@ -212,14 +197,12 @@ double Equalizer::filter(QByteArray &data, bool flush)
 void Equalizer::alloc(bool b)
 {
     QMutexLocker locker(&m_mutex);
-    if (!b && (m_fftIn || m_fftOut))
+    if (!b && (m_fftIn.isValid() || m_fftOut.isValid()))
     {
         m_canFilter = false;
         m_fftNBits = m_fftSize = 0;
-        av_fft_end(m_fftIn);
-        av_fft_end(m_fftOut);
-        m_fftIn = nullptr;
-        m_fftOut = nullptr;
+        m_fftIn.finish();
+        m_fftOut.finish();
         av_free(m_complex);
         m_complex = nullptr;
         m_input.clear();
@@ -233,13 +216,13 @@ void Equalizer::alloc(bool b)
     }
     else if (b)
     {
-        if (!m_fftIn || !m_fftOut)
+        if (!m_fftIn.isValid() || !m_fftOut.isValid())
         {
             m_fftNBits  = sets().getInt("Equalizer/nbits");
             m_fftSize   = 1 << m_fftNBits;
-            m_fftIn  = av_fft_init(m_fftNBits, false);
-            m_fftOut = av_fft_init(m_fftNBits, true);
-            m_complex = (FFTComplex *)av_malloc(m_fftSize * sizeof(FFTComplex));
+            m_fftIn.init(m_fftNBits, false);
+            m_fftOut.init(m_fftNBits, true);
+            m_complex = FFT::allocComplex(m_fftSize);
             m_input.resize(m_chn);
             m_lastSamples.resize(m_chn);
             m_windF.resize(m_fftSize);
@@ -275,7 +258,7 @@ void Equalizer::interpolateFilterCurve()
     }
 
     const int len = m_fftSize / 2;
-    if (m_f.size() != len)
+    if (static_cast<int>(m_f.size()) != len)
         m_f.resize(len);
     if (m_srate && size >= 2)
     {
