@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2023  Błażej Szczygieł
+    Copyright (C) 2010-2025  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -20,7 +20,7 @@
 
 #include <FFDecHWAccel.hpp>
 
-class FFDecDXVA2 final : public FFDecHWAccel
+class FFMPEG_EXPORT FFDecDXVA2 final : public FFDecHWAccel
 {
 public:
     FFDecDXVA2(Module &module);
@@ -37,5 +37,4 @@ public:
 private:
     AVBufferRef *m_hwDeviceBufferRef = nullptr;
     std::shared_ptr<VideoFilter> m_filter;
-    AVPixelFormat m_pixFmt = AV_PIX_FMT_NONE;
 };
