@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2024  Błażej Szczygieł
+    Copyright (C) 2010-2025  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -236,7 +236,7 @@ private:
 
 /**/
 
-FormatContext::FormatContext(bool reconnectNetwork) :
+FormatContext::FormatContext(bool reconnectNetwork, bool allowExperimental) :
     isError(false),
     currPos(0.0),
     abortCtx(new AbortContext),
@@ -244,6 +244,7 @@ FormatContext::FormatContext(bool reconnectNetwork) :
     packet(nullptr),
     oggHelper(nullptr),
     m_reconnectNetwork(reconnectNetwork),
+    m_allowExperimental(allowExperimental),
     isPaused(false), fixMkvAss(false),
     isMetadataChanged(false),
     lastTime(0.0),
@@ -394,9 +395,16 @@ bool FormatContext::getReplayGain(bool album, float &gain_db, float &peak) const
     const int streamIdx = av_find_best_stream(formatCtx, AVMEDIA_TYPE_AUDIO, -1, -1, nullptr, 0);
     if (streamIdx > -1)
     {
+        const auto stream = streams[streamIdx];
+#if LIBAVUTIL_VERSION_INT >= AV_VERSION_INT(58, 29, 100)
+        if (const auto sideData = av_packet_side_data_get(stream->codecpar->coded_side_data, stream->codecpar->nb_coded_side_data, AV_PKT_DATA_REPLAYGAIN))
+        {
+            auto replayGain = *(AVReplayGain *)sideData->data;
+#else
         if (void *sideData = av_stream_get_side_data(streams[streamIdx], AV_PKT_DATA_REPLAYGAIN, nullptr))
         {
             AVReplayGain replayGain = *(AVReplayGain *)sideData;
+#endif
             qint32  tmpGain;
             quint32 tmpPeak;
             if (replayGain.album_gain == INT32_MIN && replayGain.track_gain != INT32_MIN)
@@ -688,6 +696,8 @@ bool FormatContext::open(const QString &_url, const QString &param)
         "vplayer",
     };
 
+    m_urlTags = QMPlay2Core.getTagsForUrlStream(_url);
+
     const QByteArray scheme = Functions::getUrlScheme(_url).toUtf8();
     if (scheme.isEmpty() || scheme == "sftp")
         return false;
@@ -761,9 +771,17 @@ bool FormatContext::open(const QString &_url, const QString &param)
             av_dict_set(&options, "reconnect_on_network_error", "1", 0);
             av_dict_set(&options, "reconnect_delay_max", "7", 0);
         }
+        if (!isLocal)
+        {
+            av_dict_set(&options, "extension_picky", "0", 0);
+        }
     }
 
     formatCtx = avformat_alloc_context();
+    if (m_allowExperimental)
+    {
+        formatCtx->strict_std_compliance = FF_COMPLIANCE_EXPERIMENTAL;
+    }
     formatCtx->interrupt_callback.callback = (int(*)(void *))interruptCB;
     formatCtx->interrupt_callback.opaque = &abortCtx->isAborted;
 
@@ -880,6 +898,8 @@ bool FormatContext::open(const QString &_url, const QString &param)
     streamsOffset.resize(formatCtx->nb_streams);
     nextDts.resize(formatCtx->nb_streams);
 
+    const bool hasTeletextCodec = avcodec_find_decoder(AV_CODEC_ID_DVB_TELETEXT);
+    std::vector<StreamInfo *> subtitlesStreams;
     int nVideoStreams = 0;
     int nDefaultVideoStreams = 0;
     for (unsigned i = 0; i < formatCtx->nb_streams; ++i)
@@ -901,6 +921,12 @@ bool FormatContext::open(const QString &_url, const QString &param)
                     ++nDefaultVideoStreams;
                 ++nVideoStreams;
             }
+
+            else if (streamInfo->params->codec_type == AVMEDIA_TYPE_SUBTITLE)
+            {
+                if (hasTeletextCodec)
+                    subtitlesStreams.push_back(streamInfo);
+            }
         }
         if (!fixMkvAss && formatCtx->streams[i]->codecpar->codec_id == AV_CODEC_ID_ASS && !strncasecmp(formatCtx->iformat->name, "matroska", 8))
             fixMkvAss = true;
@@ -911,6 +937,12 @@ bool FormatContext::open(const QString &_url, const QString &param)
     }
     if (streamsInfo.isEmpty())
         return false;
+    if (subtitlesStreams.size() == 1 && subtitlesStreams[0]->params->codec_id == AV_CODEC_ID_DVB_TELETEXT)
+    {
+        // Don't skip teletext if we have decoder and it's the only stream
+        Q_ASSERT(hasTeletextCodec);
+        subtitlesStreams[0]->skip_auto_select = false;
+    }
 
     isOneStreamOgg = (name() == "ogg" && streamsInfo.count() == 1); //Workaround for OGG network streams
 
@@ -1051,8 +1083,36 @@ StreamInfo *FormatContext::getStreamInfo(AVStream *stream) const
         streamInfo->must_decode = false;
     }
 
-    streamInfo->is_default = stream->disposition & AV_DISPOSITION_DEFAULT;
+    if (streamInfo->params->codec_id == AV_CODEC_ID_DVB_TELETEXT)
+    {
+        streamInfo->skip_auto_select = true;
+    }
+
+    bool hasUrlTagDefault = false;
+    bool hasUrlTagLanguage = false;
+    for (auto &&urlTag : std::as_const(m_urlTags))
+    {
+        const auto tag = StreamInfo::getTag(urlTag.first);
+        if (tag == QMPLAY2_TAG_DEFAULT)
+        {
+            hasUrlTagDefault = true;
+            streamInfo->is_default = urlTag.second.toInt();
+        }
+        else if (tag == QMPLAY2_TAG_LANGUAGE)
+        {
+            hasUrlTagLanguage = true;
+            streamInfo->other_info += {QString::number(QMPLAY2_TAG_LANGUAGE), urlTag.second};
+        }
+        else if (tag == QMPLAY2_TAG_DRC)
+        {
+            streamInfo->other_info += {QString::number(QMPLAY2_TAG_DRC), urlTag.second};
+        }
+    }
+
+    if (!hasUrlTagDefault)
+        streamInfo->is_default = stream->disposition & AV_DISPOSITION_DEFAULT;
     streamInfo->time_base = stream->time_base;
+    streamInfo->ts_discont_possible = (formatCtx->iformat->flags & AVFMT_TS_DISCONT);
 
     if (streamInfo->params->codec_type != AVMEDIA_TYPE_ATTACHMENT)
     {
@@ -1070,7 +1130,7 @@ StreamInfo *FormatContext::getStreamInfo(AVStream *stream) const
             if (!(value = getTag(stream->metadata, "comment")).isEmpty())
                 streamInfo->other_info += {QString::number(QMPLAY2_TAG_COMMENT), value};
         }
-        if (!(value = getTag(stream->metadata, "language", false)).isEmpty() && value != "und")
+        if (!hasUrlTagLanguage && !(value = getTag(stream->metadata, "language", false)).isEmpty() && value != "und")
             streamInfo->other_info += {QString::number(QMPLAY2_TAG_LANGUAGE), value};
         if (streamInfo->params->codec_type == AVMEDIA_TYPE_VIDEO)
         {
@@ -1097,9 +1157,15 @@ StreamInfo *FormatContext::getStreamInfo(AVStream *stream) const
             if (!stillImage)
                 streamInfo->fps = stream->r_frame_rate;
 
+#if LIBAVUTIL_VERSION_INT >= AV_VERSION_INT(58, 29, 100)
+            if (const auto sideData = av_packet_side_data_get(stream->codecpar->coded_side_data, stream->codecpar->nb_coded_side_data, AV_PKT_DATA_DISPLAYMATRIX))
+            {
+                const auto rotation = av_display_rotation_get(reinterpret_cast<const int32_t *>(sideData->data));
+#else
             if (void *sideData = av_stream_get_side_data(stream, AV_PKT_DATA_DISPLAYMATRIX, nullptr))
             {
                 const auto rotation = av_display_rotation_get(reinterpret_cast<const int32_t *>(sideData));
+#endif
                 if (!qIsNaN(rotation))
                 {
                     switch(qRound(rotation))
@@ -1118,10 +1184,17 @@ StreamInfo *FormatContext::getStreamInfo(AVStream *stream) const
                 }
             }
 
+#if LIBAVUTIL_VERSION_INT >= AV_VERSION_INT(58, 29, 100)
+            if (const auto sideData = av_packet_side_data_get(stream->codecpar->coded_side_data, stream->codecpar->nb_coded_side_data, AV_PKT_DATA_SPHERICAL))
+            {
+                streamInfo->spherical = (((AVSphericalMapping *)sideData->data)->projection == AV_SPHERICAL_EQUIRECTANGULAR);
+            }
+#else
             if (void *sideData = av_stream_get_side_data(stream, AV_PKT_DATA_SPHERICAL, nullptr))
             {
                 streamInfo->spherical = (((AVSphericalMapping *)sideData)->projection == AV_SPHERICAL_EQUIRECTANGULAR);
             }
+#endif
 
             break;
         }
