@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2022  Błażej Szczygieł
+    Copyright (C) 2010-2025  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -73,7 +73,7 @@ void FileAssociation::firsttime()
             settingsW->selectAllB->click();
         layout.addWidget(settingsW);
         layout.addWidget(&bb);
-        layout.setMargin(2);
+        layout.setContentsMargins(2, 2, 2, 2);
         d.resize(0, 380);
         if (d.exec() == QDialog::Accepted)
             settingsW->saveSettings();
@@ -215,7 +215,7 @@ ModuleSettingsWidget::ModuleSettingsWidget(Module &module) :
 
     QVBoxLayout *layout = new QVBoxLayout(this);
     layout->addWidget(associateB);
-    layout->setMargin(2);
+    layout->setContentsMargins(2, 2, 2, 2);
 }
 
 void ModuleSettingsWidget::saveSettings()
