@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2024  Błażej Szczygieł
+    Copyright (C) 2010-2025  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -56,7 +56,7 @@ Inputs::Inputs() :
         set("PCM/format", 2);
     init("PCM/chn", 2);
     init("PCM/srate", 44100);
-    init("PCM/offset", 0);
+    init("PCM/offset", static_cast<int>(0));
     init("PCM/BE", false);
     init("Rayman2", true);
 }
@@ -98,8 +98,7 @@ Inputs::SettingsWidget *Inputs::getSettingsWidget()
 
 void Inputs::add()
 {
-    QWidget *parent = qobject_cast<QWidget *>(sender()->parent());
-    AddD d(*this, parent);
+    AddD d(*this, QMPlay2Core.getMainWindow());
     d.setWindowIcon(toneIcon);
     const QString params = d.execAndGet();
     if (!params.isEmpty())
@@ -316,7 +315,7 @@ void ModuleSettingsWidget::saveSettings()
     if (pcmExtsE->text().isEmpty())
         pcmExtsE->setText(g_standartExts);
     sets().set("PCM", pcmB->isChecked());
-    sets().set("PCM/extensions", pcmExtsE->text().split(';', QT_SKIP_EMPTY_PARTS));
+    sets().set("PCM/extensions", pcmExtsE->text().split(';', Qt::SkipEmptyParts));
     for (int i = 0; i < formatB.size(); ++i)
         if (formatB[i]->isChecked())
         {
