@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2022  Błażej Szczygieł
+    Copyright (C) 2010-2025  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -19,14 +19,14 @@
 #include <OpenSLESWriter.hpp>
 
 #ifdef Q_OS_ANDROID
-    #include <QAndroidJniEnvironment>
+    #include <QJniEnvironment>
     static int getNativeOutputSampleRate()
     {
         enum AudioManager
         {
             STREAM_MUSIC = 3
         };
-        QAndroidJniEnvironment jniEnv;
+        QJniEnvironment jniEnv;
         jclass clazz = jniEnv->FindClass("android/media/AudioTrack");
         jmethodID method = jniEnv->GetStaticMethodID(clazz, "getNativeOutputSampleRate", "(I)I");
         return jniEnv->CallStaticIntMethod(clazz, method, STREAM_MUSIC);
