@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2024  Błażej Szczygieł
+    Copyright (C) 2010-2025  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -34,6 +34,14 @@ bool BlendDeint::filter(QQueue<Frame> &framesQueue)
     {
         Frame videoFrame = m_internalQueue.dequeue();
         videoFrame.setNoInterlaced();
+#ifdef USE_VULKAN
+        if (videoFrame.vulkanImage())
+        {
+            auto newFrame = getNewFrame(videoFrame);
+            videoFrame.copyData(newFrame.dataArr(), newFrame.linesize());
+            videoFrame = std::move(newFrame);
+        }
+#endif
         for (int p = 0; p < 3; ++p)
         {
             const int linesize = videoFrame.linesize(p);
