@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2022  Błażej Szczygieł
+    Copyright (C) 2010-2025  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -22,6 +22,8 @@
 
 #include <QDockWidget>
 
+class QTimer;
+
 class QMPLAY2SHAREDLIB_EXPORT DockWidget : public QDockWidget
 {
     Q_OBJECT
@@ -33,8 +35,24 @@ public:
     void setTitleBarVisible(bool v);
     void setGlobalTitleBarVisible(bool v);
 
+    void setResizingByMainWindow(bool r);
+
+protected:
+    void resizeEvent(QResizeEvent *e) override;
+    void showEvent(QShowEvent *e) override;
+    void closeEvent(QCloseEvent *e) override;
+
+signals:
+    void dockVisibilityChanged(bool visible);
+    void shouldStoreSizes();
+
 private:
     QWidget *const m_emptyW;
+    QTimer *const m_visibilityTimer;
     bool m_titleBarVisible = true;
     bool m_globalTitleBarVisible = true;
+    bool m_visible = false;
+    bool m_closed = true;
+    bool m_resizingByMainWindow = false;
+    int m_lastVisible = -1;
 };
