@@ -41,6 +41,7 @@
 #include <QStyleOption>
 #include <QInputDialog>
 #include <QGuiApplication>
+#include <QVarLengthArray>
 #include <QRegularExpression>
 #if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
 # include <QInputDevice>
@@ -59,14 +60,6 @@ extern "C"
 
 using namespace std;
 
-static inline void swapArray(quint8 *a, quint8 *b, int size)
-{
-    quint8 t[size];
-    memcpy(t, a, size);
-    memcpy(a, b, size);
-    memcpy(b, t, size);
-}
-
 static inline QWindow *getNativeWindow(const QWidget *w)
 {
     if (w)
@@ -753,6 +746,14 @@ void Functions::vFlip(quint8 *data, int linesize, int height)
     int size = linesize*height, chroma_size = linesize*height/4, chroma_width = linesize/2;
     quint8 *data_s;
 
+    QVarLengthArray<quint8, 8192> t(max(linesize, chroma_width));
+    auto swapArray = [&t](quint8 *a, quint8 *b, int size) {
+        Q_ASSERT(size <= t.size());
+        memcpy(t.data(), a, size);
+        memcpy(a, b, size);
+        memcpy(b, t.data(), size);
+    };
+
     for (data_s = data + size; data_s > data;)
     {
         swapArray(data, data_s -= linesize, linesize);
@@ -793,6 +794,16 @@ quint32 Functions::getBestSampleRate()
 
 bool Functions::wrapMouse(QWidget *widget, QPoint &mousePos, int margin)
 {
+    static bool allowed =
+            QGuiApplication::platformName() == QStringLiteral("windows")
+         || QGuiApplication::platformName() == QStringLiteral("xcb")
+#if QT_VERSION >= QT_VERSION_CHECK(6, 10, 0)
+         || QGuiApplication::platformName().contains(QStringLiteral("wayland"))
+#endif
+    ;
+    if (!allowed)
+        return false;
+
     const QSize winSize = widget->size();
     bool doWrap = false;
 
@@ -1163,28 +1174,10 @@ std::pair<QString, QString> Functions::determineExtFmt(const QList<StreamInfo *>
                 ext = "opus";
                 fmt  = "ogg";
                 break;
-            case AV_CODEC_ID_H264:
-            case AV_CODEC_ID_HEVC:
-                ext = "ts";
-                fmt = "mpegts";
-                break;
             default:
                 break;
         }
     }
-    else if (streamsInfo.size() == 2)
-    {
-        const QSet<AVCodecID> codecIDs {
-            streamsInfo.at(0)->params->codec_id,
-            streamsInfo.at(1)->params->codec_id,
-        };
-        if ((codecIDs.contains(AV_CODEC_ID_AAC) || codecIDs.contains(AV_CODEC_ID_MP3) || codecIDs.contains(AV_CODEC_ID_AC3))
-                && (codecIDs.contains(AV_CODEC_ID_H264) || codecIDs.contains(AV_CODEC_ID_HEVC)))
-        {
-            ext = "ts";
-            fmt = "mpegts";
-        }
-    }
 
     return {ext, fmt};
 }
