@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2023  Błażej Szczygieł
+    Copyright (C) 2010-2025  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -25,9 +25,6 @@
 #include <Frame.hpp>
 
 #include <QGuiApplication>
-#ifdef Q_OS_WIN
-#   include <QSysInfo>
-#endif
 
 using namespace std;
 
@@ -61,7 +58,7 @@ OpenGLWriter::OpenGLWriter()
     set();
 
 #ifdef Q_OS_WIN
-    if (!QMPlay2Core.isGlOnWindow() && QSysInfo::windowsVersion() >= QSysInfo::WV_6_0)
+    if (!m_useRtt)
         m_drawable->setWindowsBypassCompositor(m_bypassCompositor);
 #endif
 }
@@ -88,7 +85,7 @@ bool OpenGLWriter::set()
             m_drawable->setX11BypassCompositor(m_bypassCompositor);
         }
 #ifdef Q_OS_WIN
-        else if (!QMPlay2Core.isGlOnWindow() && QSysInfo::windowsVersion() >= QSysInfo::WV_6_0)
+        else if (!m_useRtt)
         {
             doReset = true;
         }
@@ -118,7 +115,8 @@ bool OpenGLWriter::processParams(bool *)
         (qint16)getParam("Contrast").toInt(),
         (qint16)getParam("Saturation").toInt(),
         (qint16)getParam("Hue").toInt(),
-        (qint16)getParam("Sharpness").toInt()
+        (qint16)getParam("Sharpness").toInt(),
+        getParam("Negative").toBool(),
     };
 
     const int verticesIdx = rotate90 * 4 + flip;
@@ -281,7 +279,7 @@ void OpenGLWriter::addAdditionalParam(const QString &key)
 
 void OpenGLWriter::initialize(const shared_ptr<OpenGLHWInterop> &hwInterop)
 {
-    for (auto &&additionalParam : qAsConst(m_additionalParams))
+    for (auto &&additionalParam : std::as_const(m_additionalParams))
         removeParam(additionalParam);
     m_additionalParams.clear();
 
@@ -292,7 +290,7 @@ void OpenGLWriter::initialize(const shared_ptr<OpenGLHWInterop> &hwInterop)
     bool hasBrightness = false, hasContrast = false, hasSharpness = false;
     if (!m_drawable->videoAdjustmentKeys.isEmpty())
     {
-        for (const QString &key : qAsConst(m_drawable->videoAdjustmentKeys))
+        for (const QString &key : std::as_const(m_drawable->videoAdjustmentKeys))
         {
             if (key == "Brightness")
                 hasBrightness = true;
@@ -315,4 +313,6 @@ void OpenGLWriter::initialize(const shared_ptr<OpenGLHWInterop> &hwInterop)
         addAdditionalParam("Contrast");
     if (!hasSharpness && m_drawable->m_gl3)
         addAdditionalParam("Sharpness");
+    if (m_drawable->m_gl3)
+        addAdditionalParam("Negative");
 }
