@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2022  Błażej Szczygieł
+    Copyright (C) 2010-2025  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -25,6 +25,11 @@
 
 namespace QmVk {
 
+void HWInterop::updateInfo(const vector<Frame> &frames)
+{
+    Q_UNUSED(frames)
+}
+
 bool HWInterop::syncNow(vk::SubmitInfo &submitInfo)
 {
     if (!m_commandBuffer)
@@ -33,7 +38,7 @@ bool HWInterop::syncNow(vk::SubmitInfo &submitInfo)
         if (!device)
             return false;
 
-        m_commandBuffer = CommandBuffer::create(device->queue());
+        m_commandBuffer = CommandBuffer::create(device->firstQueue());
     }
 
     m_commandBuffer->resetAndBegin();
