@@ -1,7 +1,7 @@
 // SPDX-License-Identifier: MIT
 /*
    QmVk - simple Vulkan library created for QMPlay2
-   Copyright (C) 2020-2022 Błażej Szczygieł
+   Copyright (C) 2020-2025 Błażej Szczygieł
 */
 
 #pragma once
@@ -10,6 +10,8 @@
 
 #include <vulkan/vulkan.hpp>
 
+#include <memory>
+
 namespace QmVk {
 
 using namespace std;
@@ -30,11 +32,12 @@ public:
     };
 
 protected:
-    inline MemoryObjectBase(const shared_ptr<Device> &device);
+    MemoryObjectBase(const shared_ptr<Device> &device);
     virtual ~MemoryObjectBase() = default;
 
 public:
     inline shared_ptr<Device> device() const;
+    inline const vk::detail::DispatchLoaderDynamic &dld() const;
 
     template<typename T>
     inline T *customData();
@@ -42,7 +45,10 @@ public:
 
 protected:
     const shared_ptr<Device> m_device;
+private:
+    const vk::detail::DispatchLoaderDynamic &m_dld;
 
+protected:
     unique_ptr<CustomData> m_customData;
 };
 
@@ -54,15 +60,14 @@ T MemoryObjectBase::aligned(const T value, const T alignment)
     return (value + alignment - 1 ) & ~(alignment - 1);
 }
 
-MemoryObjectBase::MemoryObjectBase(const shared_ptr<Device> &device)
-    : m_device(device)
-{
-}
-
 shared_ptr<Device> MemoryObjectBase::device() const
 {
     return m_device;
 }
+const vk::detail::DispatchLoaderDynamic &MemoryObjectBase::dld() const
+{
+    return m_dld;
+}
 
 template<typename T>
 T *MemoryObjectBase::customData()
