@@ -1,7 +1,7 @@
 // SPDX-License-Identifier: MIT
 /*
    QmVk - simple Vulkan library created for QMPlay2
-   Copyright (C) 2020-2023 Błażej Szczygieł
+   Copyright (C) 2020-2025 Błażej Szczygieł
 */
 
 #pragma once
@@ -10,6 +10,7 @@
 
 #include <vulkan/vulkan.hpp>
 
+#include <memory>
 #include <mutex>
 
 namespace QmVk {
@@ -20,8 +21,6 @@ class Device;
 
 class QMVK_EXPORT Queue : public vk::Queue
 {
-    struct Priv {};
-
 public:
     static shared_ptr<Queue> create(
         const shared_ptr<Device> &device,
@@ -33,8 +32,7 @@ public:
     Queue(
         const shared_ptr<Device> &device,
         uint32_t queueFamilyIndex,
-        uint32_t queueIndex,
-        Priv
+        uint32_t queueIndex
     );
     ~Queue();
 
@@ -43,6 +41,7 @@ private:
 
 public:
     inline shared_ptr<Device> device() const;
+    inline const vk::detail::DispatchLoaderDynamic &dld() const;
 
     inline uint32_t queueFamilyIndex() const;
     inline uint32_t queueIndex() const;
@@ -54,6 +53,7 @@ public:
 
 private:
     const shared_ptr<Device> m_device;
+    const vk::detail::DispatchLoaderDynamic &m_dld;
     const uint32_t m_queueFamilyIndex;
     const uint32_t m_queueIndex;
 
@@ -69,6 +69,10 @@ shared_ptr<Device> Queue::device() const
 {
     return m_device;
 }
+const vk::detail::DispatchLoaderDynamic &Queue::dld() const
+{
+    return m_dld;
+}
 
 uint32_t Queue::queueFamilyIndex() const
 {
